BuildContext

Struct BuildContext 

pub struct BuildContext { /* private fields */ }
Build-time component context.

Carries information about the component being built, as well as access to the resource registry in order to acquire external resources if necessary.

Implementations

Source

impl BuildContext

pub fn new( component_context: ComponentContext, resource_registry: ResourceRegistry, ) -> Self

Creates a new BuildContext for the given component.

pub fn component_context(&self) -> &ComponentContext

Returns the context of the component being built.

pub fn component_id(&self) -> &ComponentId

Returns the component identifier.

This is the relative identifier of the component, unique within its topology but not guaranteed to be globally unique. See BuildContext::identity for the fully qualified identity.

pub fn component_type(&self) -> ComponentType

Returns the component type.

pub fn identity(&self) -> SubsystemIdentifier

Returns the fully qualified identity of this component.

The returned identifier uniquely identifies the component within the process, inclusive of the topology to which it belongs.

pub async fn acquire_resource<S: ResourceSpecification>( &self, spec: S, ) -> Result<ResourceLease<S::Resource>, AcquireError>

Acquires a resource on behalf of the component being built.

Errors

If the resource is already held elsewhere in the process, or can’t be created, an error is returned.