pub struct OneShot;Expand description
Marks a builder whose worker can only be initialized once.
Closure-based children (ComponentSpawner::noninterruptible, ComponentSpawner::interruptible) consume their
body when they start, so they can never be restarted, and ChildBuilder::with_restart_type is not available.