pub struct Restartable;Expand description
Marks a builder whose worker can be initialized more than once.
A Supervisable builds its work in initialize each time it starts, so it can be
restarted and ChildBuilder::with_restart_type is available.