pub struct ComponentContext { /* private fields */ }Expand description
A component context.
Holds the identifiers (absolute and relative) for a component, as well as its type.
Implementations
Sourceimpl ComponentContext
impl ComponentContext
Sourcepub fn new(
topology_root: &SubsystemIdentifier,
component_id: ComponentId,
component_type: ComponentType,
) -> Self
pub fn new( topology_root: &SubsystemIdentifier, component_id: ComponentId, component_type: ComponentType, ) -> Self
Creates a new ComponentContext rooted at the given topology, with the given identifier and type.
Sourcepub fn source(
topology_root: &SubsystemIdentifier,
component_id: ComponentId,
) -> Self
pub fn source( topology_root: &SubsystemIdentifier, component_id: ComponentId, ) -> Self
Creates a new ComponentContext for a source component with the given identifier, within the named topology.
Sourcepub fn relay(
topology_root: &SubsystemIdentifier,
component_id: ComponentId,
) -> Self
pub fn relay( topology_root: &SubsystemIdentifier, component_id: ComponentId, ) -> Self
Creates a new ComponentContext for a relay component with the given identifier, within the named topology.
Sourcepub fn decoder(
topology_root: &SubsystemIdentifier,
component_id: ComponentId,
) -> Self
pub fn decoder( topology_root: &SubsystemIdentifier, component_id: ComponentId, ) -> Self
Creates a new ComponentContext for a decoder component with the given identifier, within the named topology.
Sourcepub fn transform(
topology_root: &SubsystemIdentifier,
component_id: ComponentId,
) -> Self
pub fn transform( topology_root: &SubsystemIdentifier, component_id: ComponentId, ) -> Self
Creates a new ComponentContext for a transform component with the given identifier, within the named topology.
Sourcepub fn encoder(
topology_root: &SubsystemIdentifier,
component_id: ComponentId,
) -> Self
pub fn encoder( topology_root: &SubsystemIdentifier, component_id: ComponentId, ) -> Self
Creates a new ComponentContext for an encoder component with the given identifier, within the named topology.
Sourcepub fn forwarder(
topology_root: &SubsystemIdentifier,
component_id: ComponentId,
) -> Self
pub fn forwarder( topology_root: &SubsystemIdentifier, component_id: ComponentId, ) -> Self
Creates a new ComponentContext for a forwarder component with the given identifier, within the named topology.
Sourcepub fn destination(
topology_root: &SubsystemIdentifier,
component_id: ComponentId,
) -> Self
pub fn destination( topology_root: &SubsystemIdentifier, component_id: ComponentId, ) -> Self
Creates a new ComponentContext for a destination component with the given identifier, within the named topology.
Sourcepub fn component_id(&self) -> &ComponentId
pub fn component_id(&self) -> &ComponentId
Returns the component identifier.
This is the relative identifier of the component, unique within its topology but not guaranteed to be globally
unique. See ComponentContext::identity for the fully qualified identity.
Sourcepub fn component_type(&self) -> ComponentType
pub fn component_type(&self) -> ComponentType
Returns the component type.
Sourcepub fn identity(&self) -> SubsystemIdentifier
pub fn identity(&self) -> SubsystemIdentifier
Returns the fully qualified identity of this component.
The returned identifier uniquely identifies the component within the process, inclusive of the topology to which it belongs.